#!/bin/sh
echo 'name: conduit
version: 1.0.2
id: conduit-1.0.2-a73e53a4dd6fb0d7650924e804f5d2a7

license: BSD3
copyright:
maintainer: michael@snoyman.com
stability:
homepage: http://github.com/snoyberg/conduit
package-url:
synopsis: Streaming data processing library.
description: @conduit@ is a solution to the streaming data problem, allowing for production, transformation, and consumption of streams of data in constant memory. It is an alternative to lazy I\/O which guarantees deterministic resource handling, and fits in the same general solution space as @enumerator@\/@iteratee@ and @pipes@. For a tutorial, please visit <https://haskell.fpcomplete.com/user/snoyberg/library-documentation/conduit-overview>.
             .
             Release history:
             .
             [1.0] Simplified the user-facing interface back to the Source, Sink, and Conduit types, with Producer and Consumer for generic code. Error messages have been simplified, and optional leftovers and upstream terminators have been removed from the external API. Some long-deprecated functions were finally removed.
             .
             [0.5] The internals of the package are now separated to the .Internal module, leaving only the higher-level interface in the advertised API. Internally, switched to a @Leftover@ constructor and slightly tweaked the finalization semantics.
             .
             [0.4] Inspired by the design of the pipes package: we now have a single unified type underlying @Source@, @Sink@, and @Conduit@. This type is named @Pipe@. There are type synonyms provided for the other three types. Additionally, @BufferedSource@ is no longer provided. Instead, the connect-and-resume operator, @$$+@, can be used for the same purpose.
             .
             [0.3] ResourceT has been greatly simplified, specialized for IO, and moved into a separate package. Instead of hard-coding ResourceT into the conduit datatypes, they can now live around any monad. The Conduit datatype has been enhanced to better allow generation of streaming output. The SourceResult, SinkResult, and ConduitResult datatypes have been removed entirely.
             .
             [0.2] Instead of storing state in mutable variables, we now use CPS. A @Source@ returns the next @Source@, and likewise for @Sink@s and @Conduit@s. Not only does this take better advantage of GHC\'\''s optimizations (about a 20% speedup), but it allows some operations to have a reduction in algorithmic complexity from exponential to linear. This also allowed us to remove the @Prepared@ set of types. Also, the @State@ functions (e.g., @sinkState@) use better constructors for return types, avoiding the need for a dummy state on completion.
             .
             [0.1] @BufferedSource@ is now an abstract type, and has a much more efficient internal representation. The result was a 41% speedup on microbenchmarks (note: do not expect speedups anywhere near that in real usage). In general, we are moving towards @BufferedSource@ being a specific tool used internally as needed, but using @Source@ for all external APIs.
             .
             [0.0] Initial release.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules: Data.Conduit Data.Conduit.Binary Data.Conduit.Text
                 Data.Conduit.List Data.Conduit.Lazy Data.Conduit.Internal
                 Data.Conduit.Util
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/conduit-1.0.2
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/conduit-1.0.2
              /usr/local/lib
hs-libraries: HSconduit-1.0.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         bytestring-0.9.2.1-e22c77999d0db34f3ca8de7082a3ffd5
         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
         lifted-base-0.2.0.2-b90fcb9aa77776a8ad36779dc4badea7
         monad-control-0.3.1.4-1d52a0e52c2ed35102613ba7d521f3af
         resourcet-0.4.5-109dd7159142e6e05630ade009eaaed0
         text-0.11.2.3-366962ac4488fc093d5aed19e281b055
         transformers-0.3.0.0-2889ebed7e61112cda7ded5e4c153bcf
         transformers-base-0.4.1-9023dccd35c525f9deca7e00af9540a5
         void-0.5.11-5e2e8ce64c41580ed2706249cdec2c4f
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/conduit-1.0.2/html/conduit.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/conduit-1.0.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
